@@ -79,12 +79,12 @@ class Forum(object):
         else:
             posts_before = self.posts(collection_id, folder, None, since_id-1 if since_id else None, 'DESC', 40)[::-1]
             posts_next = self.posts(collection_id, folder, since_id-1 if since_id else None, None, 'ASC', 60)
-            result['last'] = [int(math.floor(float(count)/20)), last_page[-1].id]
+            result['last'] = [int(math.floor(float(count)/20)), last_page[0].id]
             result['posts'] = posts_next[:20]
             tpage = page - 1
             t_off=20
             while tpage > 1 and tpage >= page-2:
-                result['current'].append((tpage, posts_before[0-t_off].id))
+                result['current'].append((tpage, posts_before[1-t_off].id))
                 t_off += 20
                 tpage -= 1
             tpage = page
